@@ -1,15 +1,21 @@
 /*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
- *  Copyright (c) 2002-2004 Christian Loose <christian.loose@hamburg.de>
+ *  Copyright (c) 2002-2005 Christian Loose <christian.loose@kdemail.net>
  *
- * This program may be distributed under the terms of the Q Public
- * License as defined by Trolltech AS of Norway and appearing in the
- * file LICENSE.QPL included in the packaging of this file.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <qlabel.h>
@@ -22,9 +28,12 @@
 #include <kaction.h>
 #include <kapplication.h>
 #include <kfiledialog.h>
+#include <kinputdialog.h>
 #include <kinstance.h>
 #include <klocale.h>
+#include <knotifyclient.h>
 #include <kprocess.h>
+#include <kpropertiesdialog.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kxmlguifactory.h>
@@ -46,16 +55,19 @@
 #include "mergedlg.h"
 #include "historydlg.h"
 #include "updateview.h"
+#include "updateview_items.h"
 #include "protocolview.h"
-#include "cvsprogressdlg.h"
 #include "repositorydlg.h"
 #include "settingsdlg.h"
 #include "changelogdlg.h"
 #include "watchersdlg.h"
+#include "cvsinitdlg.h"
 #include "misc.h"
 #include "cvsservice_stub.h"
 #include "repository_stub.h"
-#include "globalconfig.h"
+#include "globalignorelist.h"
+#include "patchoptiondlg.h"
+#include "editwithmenu.h"
 
 #include "cervisiapart.h"
 #include "version.h"
@@ -83,22 +95,24 @@ CervisiaPart::CervisiaPart( QWidget *parentWidget, const char *widgetName,
     , opt_doCVSEdit( false )
     , recent( 0 )
     , cvsService( 0 )
-#if KDE_IS_VERSION(3,1,90)
-    , statusBar( 0 )
+    , m_statusBar(new KParts::StatusBarExtension(this))
+    , m_browserExt( 0 )
     , filterLabel( 0 )
-#endif
+    , m_editWithId(0)
+    , m_currentEditMenu(0)
+    , m_jobType(Unknown)
 {
     KGlobal::locale()->insertCatalogue("cervisia");
 
     setInstance( CervisiaFactory::instance() );
-    new CervisiaBrowserExtension( this );
+    m_browserExt = new CervisiaBrowserExtension( this );
 
     // start the cvs DCOP service
     QString error;
     QCString appId;
     if( KApplication::startServiceByDesktopName("cvsservice", QStringList(), &error, &appId) )
     {
-        KMessageBox::sorry(0, "Starting cvsservice failed with message: " +
+        KMessageBox::sorry(0, i18n("Starting cvsservice failed with message: ") +
             error, "Cervisia");
     }
     else
@@ -117,6 +131,8 @@ CervisiaPart::CervisiaPart( QWidget *parentWidget, const char *widgetName,
         Orientation o = splitHorz ? QSplitter::Vertical
                                   : QSplitter::Horizontal;
         splitter = new QSplitter(o, parentWidget, widgetName);
+        // avoid PartManager's warning that Part's window can't handle focus
+        splitter->setFocusPolicy( QWidget::StrongFocus );
 
         update = new UpdateView(*config(), splitter);
         update->setFocusPolicy( QWidget::StrongFocus );
@@ -132,24 +148,10 @@ CervisiaPart::CervisiaPart( QWidget *parentWidget, const char *widgetName,
         setWidget(splitter);
     }
     else
-        setWidget(new QLabel(i18n("This KPart is non-functional, because we "
-                                  "couldn't start the cvs DCOP service!"),
+        setWidget(new QLabel(i18n("This KPart is non-functional, because the "
+                                  "cvs DCOP service could not be started."),
                              parentWidget));
 
-#if KDE_IS_VERSION(3,1,90)
-    statusBar = new CervisiaStatusBarExtension(this);
-
-    // create the active filter indicator and add it to the statusbar
-    filterLabel = new QLabel("UR", statusBar->statusBar());
-    filterLabel->setFixedSize(filterLabel->sizeHint());
-    filterLabel->setText("");
-    QToolTip::add(filterLabel,
-                  i18n("F - All files are hidden, the tree shows only folders\n"
-                       "N - All up-to-date files are hidden\n"
-                       "R - All removed files are hidden"));
-    statusBar->addStatusBarItem(filterLabel, 0, true);
-#endif
-
     if( cvsService )
     {
         setupActions();
@@ -157,8 +159,9 @@ CervisiaPart::CervisiaPart( QWidget *parentWidget, const char *widgetName,
         connect( update, SIGNAL( selectionChanged() ), this, SLOT( updateActions() ) );
     }
 
-    setupGlobalConfig();
     setXMLFile( "cervisiaui.rc" );
+
+    QTimer::singleShot(0, this, SLOT(slotSetupStatusBar()));
 }
 
 CervisiaPart::~CervisiaPart()
@@ -192,7 +195,7 @@ bool CervisiaPart::openURL( const KURL &u )
     if( hasRunningJob )
     {
         KMessageBox::sorry(widget(),
-                           i18n("You can not change to a different folder "
+                           i18n("You cannot change to a different folder "
                                 "while there is a running cvs job."),
                            "Cervisia");
         return false;
@@ -201,6 +204,20 @@ bool CervisiaPart::openURL( const KURL &u )
     return openSandbox( u.path() );
 }
 
+
+void CervisiaPart::slotSetupStatusBar()
+{
+    // create the active filter indicator and add it to the statusbar
+    filterLabel = new QLabel("UR", m_statusBar->statusBar());
+    filterLabel->setFixedSize(filterLabel->sizeHint());
+    filterLabel->setText("");
+    QToolTip::add(filterLabel,
+                  i18n("F - All files are hidden, the tree shows only folders\n"
+                       "N - All up-to-date files are hidden\n"
+                       "R - All removed files are hidden"));
+    m_statusBar->addStatusBarItem(filterLabel, 0, true);
+}
+
 void CervisiaPart::setupActions()
 {
     KAction *action;
@@ -211,7 +228,7 @@ void CervisiaPart::setupActions()
     //
     // File Menu
     //
-    action = new KAction( i18n("O&pen Sandbox..."), "fileopen", 0,
+    action = new KAction( i18n("O&pen Sandbox..."), "fileopen", CTRL+Key_O,
                           this, SLOT( slotOpenSandbox() ),
                           actionCollection(), "file_open" );
     hint = i18n("Opens a CVS working folder in the main window");
@@ -229,14 +246,14 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Update"), "down", CTRL+Key_U,
+    action = new KAction( i18n("&Update"), "vcs_update", CTRL+Key_U,
                           this, SLOT( slotUpdate() ),
                           actionCollection(), "file_update" );
     hint = i18n("Updates (cvs update) the selected files and folders");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Status"), Key_F5,
+    action = new KAction( i18n("&Status"), "vcs_status", Key_F5,
                           this, SLOT( slotStatus() ),
                           actionCollection(), "file_status" );
     hint = i18n("Updates the status (cvs -n update) of the selected files and folders");
@@ -257,14 +274,14 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Commit..."), "up", Key_NumberSign,
+    action = new KAction( i18n("&Commit..."), "vcs_commit", Key_NumberSign,
                           this, SLOT( slotCommit() ),
                           actionCollection(), "file_commit" );
     hint = i18n("Commits the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Add to Repository..."), Key_Insert,
+    action = new KAction( i18n("&Add to Repository..."), "vcs_add", Key_Insert,
                           this, SLOT( slotAdd() ),
                           actionCollection(), "file_add" );
     hint = i18n("Adds (cvs add) the selected files to the repository");
@@ -278,7 +295,7 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Remove From Repository..."), Key_Delete,
+    action = new KAction( i18n("&Remove From Repository..."), "vcs_remove", Key_Delete,
                           this, SLOT( slotRemove() ),
                           actionCollection(), "file_remove" );
     hint = i18n("Removes (cvs remove) the selected files from the repository");
@@ -292,6 +309,11 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
+    // context menu only
+    action = new KAction( i18n("&Properties"), 0,
+                          this, SLOT( slotFileProperties() ),
+                          actionCollection(), "file_properties" );
+
     //
     // View Menu
     //
@@ -323,14 +345,14 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("&Difference to Repository (BASE)..."), CTRL+Key_D,
+    action = new KAction( i18n("&Difference to Repository (BASE)..."), "vcs_diff", CTRL+Key_D,
                           this, SLOT(slotDiffBase()),
                           actionCollection(), "view_diff_base" );
     hint = i18n("Shows the differences of the selected file to the checked out version (tag BASE)");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("Difference to Repository (HEAD)..."), CTRL+Key_H,
+    action = new KAction( i18n("Difference to Repository (HEAD)..."), "vcs_diff", CTRL+Key_H,
                           this, SLOT(slotDiffHead()),
                           actionCollection(), "view_diff_head" );
     hint = i18n("Shows the differences of the selected file to the newest version in the repository (tag HEAD)");
@@ -449,7 +471,7 @@ void CervisiaPart::setupActions()
     action = new KAction( i18n("&Lock Files"), 0,
                           this, SLOT(slotLock()),
                           actionCollection(), "lock_files" );
-    hint = i18n("Locks the selected files, so that others can't modify them");
+    hint = i18n("Locks the selected files, so that others cannot modify them");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
@@ -460,7 +482,7 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
-    action = new KAction( i18n("Create &Patch Against Repository"), 0,
+    action = new KAction( i18n("Create &Patch Against Repository..."), 0,
                           this, SLOT(slotMakePatch()),
                           actionCollection(), "make_patch" );
     hint = i18n("Creates a patch from the modifications in your sandbox");
@@ -470,6 +492,10 @@ void CervisiaPart::setupActions()
     //
     // Repository Menu
     //
+    action = new KAction( i18n("&Create..."), 0,
+                          this, SLOT(slotCreateRepository()),
+                          actionCollection(), "repository_create" );
+
     action = new KAction( i18n("&Checkout..."), 0,
                           this, SLOT(slotCheckout()),
                           actionCollection(), "repository_checkout" );
@@ -494,40 +520,46 @@ void CervisiaPart::setupActions()
     //
     // Settings menu
     //
-    action = new KToggleAction( i18n("Hide All &Files"), 0,
+    KToggleAction* toggaction = new KToggleAction( i18n("Hide All &Files"), 0,
                                 this, SLOT(slotHideFiles()),
                                 actionCollection(), "settings_hide_files" );
+    toggaction->setCheckedState(i18n("Show All &Files"));
     hint = i18n("Determines whether only folders are shown");
-    action->setToolTip( hint );
-    action->setWhatsThis( hint );
+    toggaction->setToolTip( hint );
+    toggaction->setWhatsThis( hint );
 
-    action = new KToggleAction( i18n("Hide Up-&To-Date Files"), 0,
+    toggaction = new KToggleAction( i18n("Hide Unmodified Files"), 0,
                                 this, SLOT(slotHideUpToDate()),
                                 actionCollection(), "settings_hide_uptodate" );
-    hint = i18n("Determines whether up-to-date files are hidden");
-    action->setToolTip( hint );
-    action->setWhatsThis( hint );
+    toggaction->setCheckedState(i18n("Show Unmodified Files"));
+    hint = i18n("Determines whether files with status up-to-date or "
+                "unknown are hidden");
+    toggaction->setToolTip( hint );
+    toggaction->setWhatsThis( hint );
 
-    action = new KToggleAction( i18n("Hide Removed Files"), 0,
+    toggaction = new KToggleAction( i18n("Hide Removed Files"), 0,
                                 this, SLOT(slotHideRemoved()),
                                 actionCollection(), "settings_hide_removed" );
+    toggaction->setCheckedState(i18n("Show Removed Files"));
     hint = i18n("Determines whether removed files are hidden");
-    action->setToolTip( hint );
-    action->setWhatsThis( hint );
+    toggaction->setToolTip( hint );
+    toggaction->setWhatsThis( hint );
 
-    action = new KToggleAction( i18n("Hide Non-CVS Files"), 0,
+    toggaction = new KToggleAction( i18n("Hide Non-CVS Files"), 0,
                                 this, SLOT(slotHideNotInCVS()),
                                 actionCollection(), "settings_hide_notincvs" );
+    toggaction->setCheckedState(i18n("Show Non-CVS Files"));
     hint = i18n("Determines whether files not in CVS are hidden");
-    action->setToolTip( hint );
-    action->setWhatsThis( hint );
+    toggaction->setToolTip( hint );
+    toggaction->setWhatsThis( hint );
 
-    action = new KToggleAction( i18n("Hide Empty Folders"), 0,
-                                this, SLOT(slotHideEmptyDirectories()),
-                                actionCollection(), "settings_hide_empty_directories" );
+    toggaction = new KToggleAction( i18n("Hide Empty Folders"), 0,
+                                    this, SLOT(slotHideEmptyDirectories()),
+                                    actionCollection(), "settings_hide_empty_directories" );
+    toggaction->setCheckedState(i18n("Show Empty Folders"));
     hint = i18n("Determines whether folders without visible entries are hidden");
-    action->setToolTip( hint );
-    action->setWhatsThis( hint );
+    toggaction->setToolTip( hint );
+    toggaction->setWhatsThis( hint );
 
     action = new KToggleAction( i18n("Create &Folders on Update"), 0,
                                 this, SLOT(slotCreateDirs()),
@@ -584,28 +616,65 @@ void CervisiaPart::setupActions()
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
+    //
+    // Folder context menu
+    //
+    toggaction = new KToggleAction( i18n("Unfold Folder"), 0,
+                                    this, SLOT( slotUnfoldFolder() ),
+                                    actionCollection(), "unfold_folder" );
+    toggaction->setCheckedState(i18n("Fold Folder"));
+
     //action = KStdAction::aboutApp( this, SLOT(aboutCervisia()),
     //               actionCollection(), "help_about_cervisia" );
 }
 
 
-void CervisiaPart::setupGlobalConfig()
+void CervisiaPart::popupRequested(KListView*, QListViewItem* item, const QPoint& p)
 {
-    GlobalConfig global;
+    QString xmlName = "context_popup";
 
-    KConfig* cfg = config();
-    cfg->setGroup("General");
+    if( isDirItem(item) && update->fileSelection().isEmpty() )
+    {
+        xmlName = "folder_context_popup";
+        KToggleAction* action = static_cast<KToggleAction*>(actionCollection()->action("unfold_folder"));
+        action->setChecked(item->isOpen());
+    }
 
-    global.setTimeOut(cfg->readUnsignedNumEntry("Timeout", 4000));
-}
+    if( QPopupMenu* popup = static_cast<QPopupMenu*>(hostContainer(xmlName)) )
+    {
+        if( isFileItem(item) )
+        {
+            // remove old 'Edit with...' menu
+            if( m_editWithId && popup->findItem(m_editWithId) != 0 )
+            {
+                popup->removeItem(m_editWithId);
+                delete m_currentEditMenu; 
 
+                m_editWithId      = 0;
+                m_currentEditMenu = 0;
+            }
+
+            // get name of selected file
+            QString selectedFile;
+            update->getSingleSelection(&selectedFile);
+
+            if( !selectedFile.isEmpty() )
+            {
+                KURL u;
+                u.setPath(sandbox + "/" + selectedFile);
+
+                m_currentEditMenu = new Cervisia::EditWithMenu(u, popup);
+
+                if( m_currentEditMenu->menu() )
+                    m_editWithId = popup->insertItem(i18n("Edit With"), 
+                                              m_currentEditMenu->menu(), -1, 1);
+            }
+        }
 
-void CervisiaPart::popupRequested(KListView*, QListViewItem*, const QPoint& p)
-{
-    if (QPopupMenu* popup = static_cast<QPopupMenu*>(hostContainer("context_popup")))
         popup->exec(p);
+    }
     else
-        kdDebug(8050) << "CervisiaPart: can't get XML definition for context_popup, factory()=" << factory() << endl;
+        kdDebug(8050) << "CervisiaPart: can't get XML definition for " << xmlName << ", factory()=" << factory() << endl;
 }
 
 void CervisiaPart::updateActions()
@@ -617,6 +686,12 @@ void CervisiaPart::updateActions()
     stateChanged("has_single_selection", single ? StateNoReverse
                                                 : StateReverse);
 
+    bool singleFolder = (update->multipleSelection().count() == 1);
+    stateChanged("has_single_folder", singleFolder ? StateNoReverse
+                                                   : StateReverse);
+
+    m_browserExt->setPropertiesActionEnabled(single);
+
     //    bool nojob = !( actionCollection()->action( "stop_job" )->isEnabled() );
     bool selected = (update->currentItem() != 0);
     bool nojob = !hasRunningJob && selected;
@@ -637,12 +712,14 @@ void CervisiaPart::aboutCervisia()
                           "Copyright (c) 1999-2002\n"
                           "Bernd Gehrmann <bernd@mail.berlios.de>\n"
                           "\n"
-                          "This program may be distributed under the terms of the Q Public\n"
-                          "License as defined by Trolltech AS of Norway and appearing in the\n"
-                          "file LICENSE.QPL included in the packaging of this file.\n\n"
+                          "This program is free software; you can redistribute it and/or modify\n"
+                          "it under the terms of the GNU General Public License as published by\n"
+                          "the Free Software Foundation; either version 2 of the License, or\n"
+                          "(at your option) any later version.\n"
                           "This program is distributed in the hope that it will be useful,\n"
                           "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-                          "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\n"
+                          "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+                          "GNU General Public License for more details.\n"
                           "See the ChangeLog file for a list of contributors."));
     QMessageBox::about(0, i18n("About Cervisia"),
                        aboutstr.arg(CERVISIA_VERSION).arg(KDE_VERSION_STRING));
@@ -654,7 +731,7 @@ KAboutData* CervisiaPart::createAboutData()
     KAboutData* about = new KAboutData(
                             "cervisiapart", I18N_NOOP("Cervisia Part"),
                             CERVISIA_VERSION, I18N_NOOP("A CVS frontend"),
-                            KAboutData::License_QPL,
+                            KAboutData::License_GPL,
                             I18N_NOOP("Copyright (c) 1999-2002 Bernd Gehrmann"), 0,
                             "http://www.kde.org/apps/cervisia");
 
@@ -748,7 +825,7 @@ void CervisiaPart::openFiles(const QStringList &filenames)
         KURL u;
         u.setPath(dir.absFilePath(*it));
         KRun* run = new KRun(u, 0, true, false);
-	run->setRunExecutables(false);
+        run->setRunExecutables(false);
     }
 }
 
@@ -877,6 +954,11 @@ void CervisiaPart::slotCommit()
 
     if (dlg.exec())
     {
+        // get new list of files
+        list = dlg.fileList();
+        if( list.isEmpty() )
+            return;
+
         QString msg = dlg.logMessage();
         if( !recentCommits.contains( msg ) )
         {
@@ -899,6 +981,7 @@ void CervisiaPart::slotCommit()
 
         if( protocol->startJob() )
         {
+            m_jobType = Commit;
             showJobStart(cmdline);
             connect( protocol, SIGNAL(jobFinished(bool, int)), update, SLOT(finishJob(bool, int)) );
             connect( protocol, SIGNAL(jobFinished(bool, int)), this, SLOT(slotJobFinished()) );
@@ -925,6 +1008,24 @@ void CervisiaPart::slotRemove()
 }
 
 
+void CervisiaPart::slotFileProperties()
+{
+    QString filename;
+    update->getSingleSelection(&filename);
+    if( filename.isEmpty() )
+        return;
+
+    // Create URL from selected filename
+    QDir dir(sandbox);
+
+    KURL u;
+    u.setPath(dir.absFilePath(filename));
+
+    // show file properties dialog
+    (void)new KPropertiesDialog(u);
+}
+
+
 void CervisiaPart::updateSandbox(const QString &extraopt)
 {
     QStringList list = update->multipleSelection();
@@ -1220,7 +1321,14 @@ void CervisiaPart::slotShowEditors()
 
 void CervisiaPart::slotMakePatch()
 {
-    DCOPRef job = cvsService->makePatch();
+    Cervisia::PatchOptionDialog optionDlg;
+    if( optionDlg.exec() == KDialogBase::Rejected )
+        return;
+    
+    QString format      = optionDlg.formatOption();
+    QString diffOptions = optionDlg.diffOptions();
+
+    DCOPRef job = cvsService->makePatch(diffOptions, format);
     if( !cvsService->ok() )
         return;
 
@@ -1232,6 +1340,9 @@ void CervisiaPart::slotMakePatch()
     if( fileName.isEmpty() )
         return;
 
+    if( !Cervisia::CheckOverwrite(fileName) )
+        return;
+
     QFile f(fileName);
     if( !f.open(IO_WriteOnly) )
     {
@@ -1260,7 +1371,8 @@ void CervisiaPart::slotImport()
     DCOPRef cvsJob = cvsService->import(dlg.workingDirectory(), dlg.repository(),
                                         dlg.module(), dlg.ignoreFiles(),
                                         dlg.comment(), dlg.vendorTag(),
-                                        dlg.releaseTag(), dlg.importBinary());
+                                        dlg.releaseTag(), dlg.importBinary(),
+                                        dlg.useModificationTime());
 
     // get command line from cvs job
     QString cmdline = cvsJob.call("cvsCommand()");
@@ -1274,6 +1386,26 @@ void CervisiaPart::slotImport()
 }
 
 
+void CervisiaPart::slotCreateRepository()
+{
+    Cervisia::CvsInitDialog dlg(widget());
+
+    if( !dlg.exec() )
+        return;
+
+    DCOPRef cvsJob = cvsService->createRepository(dlg.directory());
+
+    QString cmdline = cvsJob.call("cvsCommand()");
+
+    if( protocol->startJob() )
+    {
+        showJobStart(cmdline);
+        connect( protocol, SIGNAL(jobFinished(bool, int)),
+                 this,     SLOT(slotJobFinished()) );
+    }
+}
+
+
 void CervisiaPart::slotCheckout()
 {
     CheckoutDialog dlg(*config(), cvsService, CheckoutDialog::Checkout, widget());
@@ -1282,7 +1414,8 @@ void CervisiaPart::slotCheckout()
         return;
 
     DCOPRef cvsJob = cvsService->checkout(dlg.workingDirectory(), dlg.repository(),
-                                          dlg.module(), dlg.branch(), opt_pruneDirs);
+                                          dlg.module(), dlg.branch(), opt_pruneDirs,
+                                          dlg.alias(), dlg.exportOnly(), dlg.recursive());
 
     // get command line from cvs job
     QString cmdline = cvsJob.call("cvsCommand()");
@@ -1442,6 +1575,14 @@ void CervisiaPart::slotUnfoldTree()
     setFilter();
 }
 
+
+void CervisiaPart::slotUnfoldFolder()
+{
+    update->unfoldSelectedFolders();
+    setFilter();
+}
+
+
 void CervisiaPart::slotCreateDirs()
 {
     opt_createDirs = !opt_createDirs;
@@ -1534,6 +1675,14 @@ void CervisiaPart::slotJobFinished()
 
     disconnect( protocol, SIGNAL(receivedLine(QString)),
                 update,   SLOT(processUpdateLine(QString)) );
+
+    if( m_jobType == Commit )
+    {
+        KNotifyClient::event(widget()->parentWidget()->winId(), "cvs_commit_done",
+                             i18n("A CVS commit to repository %1 is done")
+                             .arg(repository));
+        m_jobType = Unknown;
+    }
 }
 
 
@@ -1578,6 +1727,16 @@ bool CervisiaPart::openSandbox(const QString &dirname)
     // set m_url member for tabbed window modus of Konqueror
     m_url = KURL::fromPathOrURL(sandbox);
 
+    // *NOTICE*
+    // The order is important here. We have to set the m_url member before
+    // calling this function because the progress dialog uses the enter_loop()/
+    // exit_loop() methods. Those methods result in a call to queryExit() in
+    // cervisiashell.cpp which then uses the m_url member to save the last used
+    // directory.
+    if( cvsRepository.retrieveCvsignoreFile() )
+        Cervisia::GlobalIgnoreList().retrieveServerIgnoreList(cvsService,
+                                                              repository);
+
     QDir::setCurrent(sandbox);
     update->openDirectory(sandbox);
     setFilter();
@@ -1628,110 +1787,11 @@ void CervisiaPart::setFilter()
                 str += "R";
         }
 
-#if KDE_IS_VERSION(3,1,90)
-    filterLabel->setText(str);
-#endif
+    if( filterLabel )
+        filterLabel->setText(str);
 }
 
 
-#if 0
-void CervisiaPart::parseStatus(QString pathname, QStrList list)
-{
-    char buf[512];
-    QString command;
-    QString dirpath;
-    QString name, statusstr, version;
-    enum { Begin, File, FileSep, WorkRev, FinalSep } state;
-
-    QString line = joinLine(list);
-
-    command = "cd ";
-    command += KProcess::quote(pathname);
-    command += " && " + cvsClient(repository) + " status -l ";
-    command += line;
-    //command += " 2>&1";
-
-    FILE *f = popen(QFile::encodeName(command), "r");
-    if (!f)
-        return;
-
-    state = Begin;
-    while (fgets(buf, sizeof buf, f))
-        {
-            QCString line = buf;
-            chomp(&line);
-            //DEBUGOUT( "Line: " << line );
-            switch (state)
-                {
-                case Begin:
-                    if (line.left(22) == "cvs status: Examining ")
-                        dirpath = line.right(line.length()-22);
-                    state = File;
-                    //DEBUGOUT( "state = file" );
-                    break;
-                case File:
-                    if (line.length() > 32 &&
-                        line.left(6) == "File: " &&
-                        line.mid(24, 8) == "Status: ")
-                    {
-                        name = line.mid(6, 18).stripWhiteSpace();
-                        if (dirpath != ".")
-                            name.prepend("/").prepend(dirpath);
-                        statusstr = line.right(line.length()-32)
-                                        .stripWhiteSpace();
-                        state = FileSep;
-                        //DEBUGOUT( "state = FileSep" );
-                    }
-                    break;
-                case FileSep:
-                    if (!line.isEmpty()) // Error
-                        state = WorkRev;
-                    //DEBUGOUT( "state = WorkRev" );
-                    break;
-                case WorkRev:
-                    if (line.left(21) == "   Working revision:\t")
-                    {
-                        int pos;
-                        version = line.right(line.length()-21);
-                        if ( (pos = version.find(" ")) != -1 )
-                            version.truncate(pos);
-                        state = FinalSep;
-                        //DEBUGOUT( "state = FinalSep" );
-                    }
-                    break;
-                case FinalSep:
-                    if (line == "")
-                    {
-                        //DEBUGOUT( "Adding: " << name <<
-                        //          "Status: " << statusstr << "Version: " << version );
-                        UpdateView::Status status = UpdateView::Unknown;
-                        if (statusstr == "Up-to-date")
-                            status = UpdateView::UpToDate;
-                        else if (statusstr == "Locally Modified")
-                            status = UpdateView::LocallyModified;
-                        else if (statusstr == "Locally Added")
-                            status = UpdateView::LocallyAdded;
-                        else if (statusstr == "Locally Removed")
-                            status = UpdateView::LocallyRemoved;
-                        else if (statusstr == "Needs Checkout")
-                            status = UpdateView::NeedsUpdate;
-                        else if (statusstr == "Needs Patch")
-                            status = UpdateView::NeedsPatch;
-                        else if (statusstr == "Needs Merge")
-                            status = UpdateView::NeedsMerge;
-                        else if (statusstr == "File had conflicts on merge")
-                            status = UpdateView::Conflict;
-                        //update->addEntry(status, name /*, version*/);
-                        state = Begin;
-                        //DEBUGOUT( "state = Begin" );
-                    }
-                }
-        }
-    pclose(f);
-}
-#endif
-
-
 void CervisiaPart::readSettings()
 {
     KConfig* config = CervisiaFactory::instance()->config();
@@ -1830,7 +1890,10 @@ void CervisiaPart::guiActivateEvent(KParts::GUIActivateEvent* event)
         updateActions();
     }
 
-    KParts::ReadOnlyPart::guiActivateEvent(event);
+    // don't call this as it overwrites Konqueror's caption (if you have a
+    // Konqueror with more than one view and switch back to Cervisia)
+    //
+    // KParts::ReadOnlyPart::guiActivateEvent(event);
 }
 
 
@@ -1845,6 +1908,18 @@ CervisiaBrowserExtension::~CervisiaBrowserExtension()
 
 }
 
+
+void CervisiaBrowserExtension::setPropertiesActionEnabled(bool enabled)
+{
+    emit enableAction("properties", enabled);
+}
+
+
+void CervisiaBrowserExtension::properties()
+{
+    static_cast<CervisiaPart*>(parent())->slotFileProperties();
+}
+
 // Local Variables:
 // c-basic-offset: 4
 // End:
