@@ -1,7 +1,7 @@
-/* 
+/*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
- *  Copyright (c) 2002-2003 Christian Loose <christian.loose@hamburg.de>
+ *  Copyright (c) 2002-2005 Christian Loose <christian.loose@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,21 +15,24 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "commitdlg.h"
 
 #include <qcombobox.h>
+#include <qcheckbox.h>
+#include <qdir.h>
 #include <qfileinfo.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlistbox.h>
-#include <ktextedit.h>
+#include <qheader.h>
+#include <klistview.h>
 #include <kconfig.h>
 #include <klocale.h>
 
 #include "cvsservice_stub.h"
+#include "logmessageedit.h"
 #include "diffdlg.h"
 
 
@@ -47,11 +50,16 @@ CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service,
     QLabel *textlabel = new QLabel( i18n("Commit the following &files:"), mainWidget );
     layout->addWidget(textlabel);
 
-    listbox = new QListBox(mainWidget);
-    textlabel->setBuddy(listbox);
-    connect( listbox, SIGNAL(selected(int)), this, SLOT(fileSelected(int)));
-    connect( listbox, SIGNAL(highlighted(int)), this, SLOT(fileHighlighted(int)));
-    layout->addWidget(listbox, 5);
+    m_fileList = new KListView(mainWidget);
+    m_fileList->addColumn("");
+    m_fileList->setFullWidth(true);
+    m_fileList->header()->hide();
+    textlabel->setBuddy(m_fileList);
+    connect( m_fileList, SIGNAL(doubleClicked(QListViewItem*)),
+             this, SLOT(fileSelected(QListViewItem*)));
+    connect( m_fileList, SIGNAL(selectionChanged()),
+             this, SLOT(fileHighlighted()) );
+    layout->addWidget(m_fileList, 5);
 
     QLabel *archivelabel = new QLabel(i18n("Older &messages:"), mainWidget);
     layout->addWidget(archivelabel);
@@ -66,13 +74,19 @@ CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service,
     QLabel *messagelabel = new QLabel(i18n("&Log message:"), mainWidget);
     layout->addWidget(messagelabel);
 
-    edit = new KTextEdit(mainWidget);
+    edit = new Cervisia::LogMessageEdit(mainWidget);
     messagelabel->setBuddy(edit);
     edit->setCheckSpellingEnabled(true);
     edit->setFocus();
     edit->setMinimumSize(400, 100);
     layout->addWidget(edit, 10);
 
+    m_useTemplateChk = new QCheckBox(i18n("Use log message &template"), mainWidget);
+    layout->addWidget(m_useTemplateChk);
+    connect( m_useTemplateChk, SIGNAL(clicked()), this, SLOT(useTemplateClicked()) );
+
+    checkForTemplateFile();
+
     setButtonGuiItem(User1, KGuiItem(i18n("&Diff"), "vcs_diff"));
     enableButton(User1, false);
     connect( this, SIGNAL(user1Clicked()),
@@ -88,26 +102,50 @@ CommitDialog::CommitDialog(KConfig& cfg, CvsService_stub* service,
 CommitDialog::~CommitDialog()
 {
     saveDialogSize(partConfig, "CommitDialog");
+
+    KConfigGroupSaver cs(&partConfig, "CommitDialog");
+    partConfig.writeEntry("UseTemplate", m_useTemplateChk->isChecked());
 }
 
 
 void CommitDialog::setFileList(const QStringList &list)
 {
-    listbox->insertStringList(list);
+    QString currentDirName = QFileInfo(QChar('.')).absFilePath();
 
-    // the dot for the root directory is hard to see, so
-    // we convert it to the absolut path
-    if (const QListBoxItem* item = listbox->findItem(QChar('.'), Qt::ExactMatch))
+    QStringList::ConstIterator it = list.begin();
+    for( ; it != list.end(); ++it )
     {
-        listbox->changeItem(QFileInfo(QChar('.')).absFilePath(),
-                            listbox->index(item));
+        // the dot for the root directory is hard to see, so
+        // we convert it to the absolut path
+        QString text = (*it != "." ? *it : currentDirName);
+
+        edit->compObj()->addItem(text);
+        QCheckListItem* item = new QCheckListItem(m_fileList, text, QCheckListItem::CheckBox);
+        item->setOn(true);
     }
 }
 
 
+QStringList CommitDialog::fileList() const
+{
+    QStringList files;
+
+    QListViewItemIterator it(m_fileList, QListViewItemIterator::Checked);
+    for( ; it.current(); ++it )
+    {
+        files.append(it.current()->text(0));
+    }
+
+    return files;
+}
+
+
 void CommitDialog::setLogMessage(const QString &msg)
 {
     edit->setText(msg);
+
+    if( m_useTemplateChk->isChecked() )
+        addTemplateText();
 }
 
 
@@ -146,14 +184,14 @@ void CommitDialog::comboActivated(int index)
 {
     if (index == current_index)
         return;
-    
+
     if (index == 0) // Handle current text
         edit->setText(current_text);
     else
         {
             if (current_index == 0) // Store current text
                 current_text = edit->text();
-            
+
             // Show archived text
             edit->setText(commits[index-1]);
         }
@@ -161,30 +199,30 @@ void CommitDialog::comboActivated(int index)
 }
 
 
-void CommitDialog::fileSelected(int index)
+void CommitDialog::fileSelected(QListViewItem* item)
 {
-    QListBoxItem *item = listbox->item(index);
-    if ( !item )
+    // double click on empty space?
+    if( !item )
         return;
 
-    showDiffDialog(item->text());
+    showDiffDialog(item->text(0));
 }
 
 
-void CommitDialog::fileHighlighted(int index)
+void CommitDialog::fileHighlighted()
 {
-    highlightedFile = index;
-    enableButton(User1, true);
+    bool isItemSelected = (m_fileList->selectedItem() != 0);
+    enableButton(User1, isItemSelected);
 }
 
 
 void CommitDialog::diffClicked()
 {
-    QListBoxItem *item = listbox->item(highlightedFile);
-    if ( !item )
+    QListViewItem* item = m_fileList->selectedItem();
+    if( !item )
         return;
 
-    showDiffDialog(item->text());
+    showDiffDialog(item->text(0));
 }
 
 
@@ -205,6 +243,64 @@ void CommitDialog::showDiffDialog(const QString& fileName)
 }
 
 
+void CommitDialog::useTemplateClicked()
+{
+    if( m_useTemplateChk->isChecked() )
+    {
+        addTemplateText();
+    }
+    else
+    {
+        removeTemplateText();
+    }
+}
+
+
+void CommitDialog::checkForTemplateFile()
+{
+    QString filename = QDir::current().absPath() + "/CVS/Template";
+    if( QFile::exists(filename) )
+    {
+        QFile f(filename);
+        if( f.open(IO_ReadOnly) )
+        {
+            QTextStream stream(&f);
+            m_templateText = stream.read();
+            f.close();
+
+            m_useTemplateChk->setEnabled(true);
+            KConfigGroupSaver cs(&partConfig, "CommitDialog");
+            bool check = partConfig.readBoolEntry("UseTemplate", true);
+            m_useTemplateChk->setChecked(check);
+
+            addTemplateText();
+        }
+        else
+        {
+            m_useTemplateChk->setEnabled(false);
+        }
+    }
+    else
+    {
+        m_useTemplateChk->setEnabled(false);
+    }
+}
+
+
+void CommitDialog::addTemplateText()
+{
+    edit->append(m_templateText);
+    edit->moveCursor(QTextEdit::MoveHome, false);
+    edit->ensureCursorVisible();
+}
+
+
+void CommitDialog::removeTemplateText()
+{
+    edit->setText(edit->text().remove(m_templateText));
+}
+
+
 #include "commitdlg.moc"
 
 
