@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -26,11 +26,13 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <qfile.h>
+#include <qfileinfo.h>
 #include <qregexp.h>
 #include <qstringlist.h>
 #include <kconfig.h>
 #include <kemailsettings.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include <kprocess.h>
 #include <ktempfile.h>
 #include <kuser.h>
@@ -204,6 +206,25 @@ QString Cervisia::NormalizeRepository(const QString& repository)
 }
 
 
+bool Cervisia::CheckOverwrite(const QString& fileName, QWidget* parent)
+{
+    bool result = true;
+
+    QFileInfo fi(fileName);
+
+    // does the file already exist?
+    if( fi.exists() )
+    {
+        result = (KMessageBox::warningContinueCancel(parent,
+                  i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(fileName),
+                  i18n("Overwrite File?"),
+                  KGuiItem(i18n("&Overwrite"), "filesave", i18n("Overwrite the file"))) == KMessageBox::Continue);
+    }
+
+    return result;
+}
+
+
 QString joinLine(const QStringList &list)
 {
     QString line;
@@ -267,7 +288,7 @@ void cleanupTempFiles()
 }
 
 
-QString tempFileName(const QString &suffix)
+QString tempFileName(const QString& suffix)
 {
     if (!tempFiles)
         tempFiles = new QStringList;
