@@ -2,13 +2,19 @@
  * Copyright (C) 1999-2002 Bernd Gehrmann <bernd@mail.berlios.de>
  * Copyright (c) 2003-2005 Andr Wbbeking <Woebbeking@web.de>
  *
- * This program may be distributed under the terms of the Q Public
- * License as defined by Trolltech AS of Norway and appearing in the
- * file LICENSE.QPL included in the packaging of this file.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -23,6 +29,7 @@
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kmimetype.h>
 
 #include "cvsdir.h"
 #include "entry.h"
@@ -605,6 +612,9 @@ int UpdateFileItem::compare(QListViewItem* i,
     case Name:
         iResult = entry().m_name.localeAwareCompare(item->entry().m_name);
         break;
+    case MimeType:
+        iResult = KMimeType::findByPath(entry().m_name)->comment().localeAwareCompare(KMimeType::findByPath(item->entry().m_name)->comment());
+        break;
     case Status:
         if ((iResult = ::compare(statusClass(), item->statusClass())) == 0)
             iResult = entry().m_name.localeAwareCompare(item->entry().m_name);
@@ -632,6 +642,9 @@ QString UpdateFileItem::text(int column) const
     case Name:
         result = entry().m_name;
         break;
+    case MimeType:
+	result = KMimeType::findByPath(entry().m_name)->comment();
+	break;
     case Status:
         result = toString(entry().m_status);
         break;
