@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -80,11 +80,11 @@ void CVSHandler::setPOTBaseDir( const QString& dir )
   emit signalIsPOTRepository( _isPOTRepository );
 }
 
-QString CVSHandler::fileStatus( const QString& filename )
+QString CVSHandler::fileStatus( const FileStatus status ) const
 {
-  switch ( fstatus( filename ) ) {
+  switch ( status ) {
     case NO_REPOSITORY:
-      return i18n( "No repository" );
+      return i18n( "No CVS repository" );
       break;
     case NOT_IN_CVS:
       return i18n( "Not in CVS" );
@@ -110,7 +110,7 @@ QString CVSHandler::fileStatus( const QString& filename )
   }
 }
 
-CVSHandler::FileStatus CVSHandler::fstatus( const QString& filename )
+CVSHandler::FileStatus CVSHandler::fstatus( const QString& filename ) const
 {
   // no valid repository
   if ( !_isPORepository )
@@ -126,19 +126,21 @@ CVSHandler::FileStatus CVSHandler::fstatus( const QString& filename )
   if ( !entries.open( IO_ReadOnly ) )
     return NOT_IN_CVS;  // we already know that it's a repository
 
+  // ### FIXME: it does not take care of CVS/Entries.Log
   // a line in CVS/Entries has the following format:
   // [D]/NAME/REVISION/[CONFLICT+]TIMESTAMP/OPTIONS/TAGDATE
   QRegExp rx( QString( "^D?/%1/" ).arg( info.fileName( ) ) );
 
   QString temp;
-  QStringList fields;
   QTextStream stream( &entries );
 
   bool isInRepository = false;
-  while ( !( stream.atEnd( ) || isInRepository ) ) {
+  while ( !stream.atEnd() ) {
     temp = stream.readLine( );
-    if ( temp.find( rx ) == 0 )
+    if ( temp.find( rx ) == 0 ) {
       isInRepository = true;
+      break;
+    }
   }
   entries.close( );
 
@@ -146,11 +148,11 @@ CVSHandler::FileStatus CVSHandler::fstatus( const QString& filename )
   if ( !isInRepository )
     return NOT_IN_CVS;
 
-  fields = QStringList::split( '/', temp, true );
+  const QStringList fields = QStringList::split( '/', temp, true );
   // bool isDir = ( fields[0] == "D" );
-  QString cvsname( fields[1] );
-  QString revision( fields[2] );
-  QString timestamp( fields[3] );
+  const QString cvsname( fields[1] );
+  const QString revision( fields[2] );
+  const QString timestamp( fields[3] );
   // ignore the other fields for now
 
   if ( revision == "0" && timestamp == "dummy timestamp" )
@@ -159,18 +161,12 @@ CVSHandler::FileStatus CVSHandler::fstatus( const QString& filename )
     return LOCALLY_REMOVED;
 
   // check for conflicts
-  bool hasConflicts = false;
-  if ( timestamp.find( '+' ) >= 0 ) {
-    hasConflicts = true;
-    timestamp.remove( QRegExp( ".*\\+" ) );
-  }
-
-  if ( hasConflicts )
+  if ( timestamp.find( '+' ) >= 0 )
     return CONFLICT;
 
   // calculate the UTC time from the file's last modified date
   struct stat st;
-  lstat( fn.local8Bit( ), &st );
+  lstat( QFile::encodeName(fn), &st );
   struct tm * tm_p = gmtime( &st.st_mtime );
   QString ftime = QString( asctime( tm_p ) );
   ftime.truncate( ftime.length( ) - 1 );
@@ -185,21 +181,23 @@ QString CVSHandler::cvsStatus( const QString& filename ) const
   return map[filename];
 }
 
-void CVSHandler::execCVSCommand(CVS::Command cmd, const QString& filename, bool templates)
+void CVSHandler::execCVSCommand( QWidget* parent, CVS::Command cmd, const QString& filename, bool templates)
 {
   if ( !_isPORepository ) {
     // This message box should never be visible but who knows... ;-)
-    KMessageBox::sorry( 0, i18n( "This is not a valid CVS repository. "
+    KMessageBox::sorry( parent, i18n( "This is not a valid CVS repository. "
       "The CVS commands cannot be executed." ) );
     return;
   }
 
   QFileInfo info( filename );
   if ( !info.isDir( ) ) {
-    execCVSCommand(cmd, QStringList( filename ), templates);
+    execCVSCommand( parent, cmd, QStringList( filename ), templates );
     return;
   }
 
+  // ### FIXME: instead of making a QString, use KProcess directly, so that it cares about quoting.
+  // ### FIXME: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
   // it's a dir
   QString command( "cd " + filename + " && cvs " );
   switch ( cmd ) {
@@ -207,7 +205,8 @@ void CVSHandler::execCVSCommand(CVS::Command cmd, const QString& filename, bool
       command += "update -dP";
       break;
     case CVS::Commit:
-      command += "commit -m @LOGMESSAGE@";
+      // The cvs client does not care about the encoding, so we cannot set anything here
+      command += "commit -F @LOG@FILE@";
       checkToAdd( QStringList( filename ) );
       break;
     case CVS::Status:
@@ -218,26 +217,27 @@ void CVSHandler::execCVSCommand(CVS::Command cmd, const QString& filename, bool
       break;
   }
 
-  showDialog( cmd, QStringList( filename ), command );
+  showDialog( parent, cmd, QStringList( filename ), command );
 }
 
-void CVSHandler::execCVSCommand(CVS::Command cmd, const QStringList& files, bool templates)
+void CVSHandler::execCVSCommand( QWidget* parent, CVS::Command cmd, const QStringList& files, bool templates )
 {
   if ( !_isPORepository ) {
     // This message box should never be visible but who knows... ;-)
-    KMessageBox::sorry( 0, i18n( "This is not a valid CVS repository. "
+    KMessageBox::sorry( parent, i18n( "This is not a valid CVS repository. "
       "The CVS commands cannot be executed." ) );
     return;
   }
 
-  QStringList::ConstIterator it;
+  // ### FIXME: instead of making a QString, use KProcess directly, so that it cares about quoting.
+  // ### FIXME: use KProcess::setWorkingDirectory instead of using "cd" (therefore allowing to use KProcess without a shell.)
   QString command("cd " + (templates ? _potBaseDir : _poBaseDir) + " && cvs ");
   switch ( cmd ) {
     case CVS::Update:
       command += "update -dP";
       break;
     case CVS::Commit:
-      command += "commit -m @LOGMESSAGE@";
+      command += "commit -F @LOG@FILE@";
       checkToAdd( files );
       break;
     case CVS::Status:
@@ -254,13 +254,14 @@ void CVSHandler::execCVSCommand(CVS::Command cmd, const QStringList& files, bool
   else
     rx.setPattern(_poBaseDir + "/?");
 
+  QStringList::ConstIterator it;
   for ( it = files.begin( ); it != files.end( ); ++it ) {
     QString temp = *it;
     temp.remove(rx);
     command += " \'" + temp + "\'";
   }
 
-  showDialog( cmd, files, command );
+  showDialog( parent, cmd, files, command );
 }
 
 void CVSHandler::setAutoUpdateTemplates( bool update )
@@ -268,9 +269,9 @@ void CVSHandler::setAutoUpdateTemplates( bool update )
   _autoUpdateTemplates = update;
 }
 
-void CVSHandler::showDialog( CVS::Command cmd, const QStringList& files, const QString& commandLine )
+void CVSHandler::showDialog( QWidget* parent, CVS::Command cmd, const QStringList& files, const QString& commandLine )
 {
-  CVSDialog * dia = new CVSDialog( cmd, 0, "CVS DIALOG", true );
+  CVSDialog * dia = new CVSDialog( cmd, parent, "CVS DIALOG", true );
   dia->setFiles( files );
   dia->setCommandLine( commandLine );
   if ( cmd == CVS::Commit ) {
@@ -381,4 +382,16 @@ void CVSHandler::processDiff( QString output )
     KMessageBox::error( 0, error );
 }
 
+bool CVSHandler::isConsideredModified( const FileStatus status ) const
+{
+  /*
+   * A file is modified if it is either:
+   * - locally modified for CVS
+   * - directory under CVS control but not the file
+   */
+   return status == LOCALLY_MODIFIED || status == NOT_IN_CVS;
+}
+
+
+
 #include "cvshandler.moc"
