@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -188,10 +188,11 @@ int main(int argc, char **argv)
     about.addAuthor("Matthias Kiefer",I18N_NOOP("Original author"),"kiefer@kde.org");
     about.addAuthor("Stanislav Visnovsky",I18N_NOOP("Current maintainer, porting to KDE3/Qt3.")
                     ,"visnovsky@kde.org");
+    about.addAuthor("Nicolas Goutte", 0, "goutte@kde.org");
 
     about.addCredit("Claudiu Costin",I18N_NOOP("Wrote documentation and sent "
                                                "many bug reports and suggestions for improvements.")
-                    ,"claudiuc@geocities.com");
+                    ,"claudiuc@kde.org");
     about.addCredit("Thomas Diehl",I18N_NOOP("Gave many suggestions for the GUI "
                                              "and the behavior of KBabel. He also contributed the beautiful splash screen.")
                     ,"thd@kde.org");
@@ -207,11 +208,10 @@ int main(int argc, char **argv)
 					,"suse@suse.de","http://www.suse.de");
     about.addCredit("Bram Schoenmakers",I18N_NOOP("Support for making diffs and some minor "
                                                   "improvements."),"bramschoenmakers@kde.nl");
-    about.addCredit("", I18N_NOOP("KBabel contains code from the following projects:\n"
-                                  "Qt by Trolltech and GNU gettext"));
 
-    about.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\nYour names")
-                        ,I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"));
+    about.addCredit("Trolltech", I18N_NOOP("KBabel contains code from Qt"), 0, "http://www.trolltech.com");
+
+    about.addCredit("GNU gettext", I18N_NOOP("KBabel contains code from GNU gettext"), 0, "http://www.gnu.org/software/gettext/");
 
     // Initialize command line args
     KCmdLineArgs::init(argc, argv, &about);
