@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -87,6 +87,16 @@ Catalog::~Catalog()
     delete d;
 }
 
+QString Catalog::msgctxt(uint index) const
+{
+    if (  d->_entries.isEmpty() )
+        return QString::null;
+   uint max=d->_entries.count()-1;
+   if(index > max)
+      index=max;
+   return d->_entries[index].msgctxt();
+}
+
 QStringList Catalog::msgid(uint index, const bool noNewlines) const
 {
    if (  d->_entries.isEmpty() )
@@ -315,8 +325,8 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
    QString temp;
    bool found;
 
-   IdentitySettings identityOptions = identitySettings();
-   SaveSettings saveOptions = saveSettings();
+   const IdentitySettings identityOptions = identitySettings();
+   const SaveSettings saveOptions = saveSettings();
    
    if(!usePrefs || saveOptions.updateLastTranslator)
    {
@@ -332,7 +342,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          if((*it).contains(QRegExp("^ *Last-Translator:.*")))
          {
-            (*it).replace(QRegExp("^ *Last-Translator:.*"),temp);
+            (*it) = temp;
             found=true;
          }
        }
@@ -351,7 +361,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          if((*it).contains(QRegExp("^ *PO-Revision-Date:.*")))
          {
-            (*it).replace(QRegExp("^ *PO-Revision-Date:.*"),temp);
+            (*it) = temp;
             found=true;
          }
        }
@@ -371,7 +381,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          if((*it).contains(QRegExp("^ *Project-Id-Version:.*")))
          {
-            (*it).replace(QRegExp("^ *Project-Id-Version:.*"),temp);
+            (*it) = temp;
             found=true;
          }
        }
@@ -394,36 +404,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          if((*it).contains(QRegExp("^ *Language-Team:.*")))
          {
-            (*it).replace(QRegExp("^ *Language-Team:.*"),temp);
-            found=true;
-         }
-       }
-       if(!found)
-       {
-          headerList.append(temp);
-       }
-   }
-   if(!usePrefs || saveOptions.updateCharset)
-   {
-      found=false;
-
-	  QString encodingStr;
-      if(saveOptions.useOldEncoding && d->fileCodec)
-      {
-		  encodingStr = charsetString(d->fileCodec);
-      }
-      else
-      {
-          encodingStr=charsetString(saveOptions.encoding);
-      }
-      temp="Content-Type: text/plain; charset="+encodingStr+"\\n";
-      QString charsettemp="; charset="+encodingStr+"\\n";
-
-      for( it = headerList.begin(); it != headerList.end(); ++it )
-      {
-         if((*it).contains(QRegExp("^ *Content-Type:.*;\\s*charset=")))
-         {
-            (*it).replace(QRegExp(";\\s*charset\\s*=\\s*[^\\\"\\n]+"),charsettemp);
+            (*it) = temp;
             found=true;
          }
        }
@@ -432,6 +413,57 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
           headerList.append(temp);
        }
    }
+    if(!usePrefs || saveOptions.updateCharset)
+    {
+        found=false;
+    
+        QString encodingStr;
+        if(saveOptions.useOldEncoding && d->fileCodec)
+        {
+            encodingStr = charsetString(d->fileCodec);
+        }
+        else
+        {
+            encodingStr=charsetString(saveOptions.encoding);
+        }
+        it = headerList.begin();
+        while( it != headerList.end() )
+        {
+            if( (*it).find( QRegExp( "^ *Content-Type:.*" ) ) != -1 )
+            {
+                if ( found )
+                {
+                    // We had already a Content-Type, so we do not need a duplicate
+                    it = headerList.remove( it );
+                }
+                else
+                {
+                    found=true;
+                    QRegExp regexp( "^ *Content-Type:(.*/.*);?\\s*charset=.*$" );
+                    QString mimeType;
+                    if ( regexp.search( *it ) )
+                    {
+                        mimeType = regexp.cap( 1 ).stripWhiteSpace();
+                    }
+                    if ( mimeType.isEmpty() )
+                    {
+                        mimeType = "text/plain";
+                    }
+                    temp = "Content-Type: ";
+                    temp += mimeType;
+                    temp += "; charset=";
+                    temp += encodingStr;
+                    temp += "\\n";
+                    (*it) = temp;
+                }
+            }
+            ++it;
+        }
+        if(!found)
+        {
+            headerList.append(temp);
+        }
+    }
    if(!usePrefs || saveOptions.updateEncoding)
    {
       found=false;
@@ -442,7 +474,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          if((*it).contains(QRegExp("^ *Content-Transfer-Encoding:.*")))
          {
-            (*it).replace(QRegExp("^ *Content-Transfer-Encoding:.*"),temp);
+            (*it) = temp;
             found=true;
          }
        }
@@ -460,7 +492,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
    {
       if((*it).contains(QRegExp("^ *X-Generator:.*")))
       {
-         (*it).replace(QRegExp("^ *X-Generator:.*"),temp);
+         (*it) = temp;
          found=true;
       }
     }
@@ -476,8 +508,8 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
    {
 	if((*it).contains(QRegExp("^ *MIME-Version:")))
     	{
-    	    found=true;
-	    break;
+         (*it) = temp;
+         found=true;
     	}
    }
    if( !found )
@@ -497,25 +529,17 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 	{
     	    if((*it).contains(QRegExp("^ *Plural-Forms:")))
     	    {
-        	(*it).replace(QRegExp("^ *Plural-Forms:.*"),temp);
+        	(*it) = temp;
         	found=true;
     	    }
 	}
-    }
-    if(!found && !identityOptions.gnuPluralFormHeader.isEmpty() )
-    {
-       headerList.append(temp);
-    }
-
-   QString msgstr;
-   for( it = headerList.begin(); it != headerList.end(); ++it )
-   {
-      msgstr+=("\n"+(*it));
+        if( !found )
+        {
+            headerList.append(temp);
+        }
    }
 
-   msgstr.remove(0,1);// remove first newline
-
-   oldHeader.setMsgstr(msgstr);
+   oldHeader.setMsgstr( headerList.join( "\n" ) );
 
    //comment = description, copyrights
    if(!usePrefs || (saveOptions.FSFCopyright != ProjectSettingsBase::NoChange))
@@ -524,7 +548,8 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 
       for( it = commentList.begin(); it != commentList.end(); ++it )
       {
-         if((*it).contains(QRegExp("^# *Copyright \\(C\\).*Free Software Foundation, Inc")))
+         // U+00A9 is the Copyright sign
+         if ( (*it).find( QRegExp("^# *Copyright (\\(C\\)|\\x00a9).*Free Software Foundation, Inc") ) != -1 )
          {
             found=true;
 	    break;
@@ -532,11 +557,11 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
        }
        if(found)
        {
-	    if((*it).contains(QRegExp("^# *Copyright \\(C\\) YEAR Free Software Foundation, Inc\\.")))
+            if ( (*it).find( QRegExp("^# *Copyright (\\(C\\)|\\x00a9) YEAR Free Software Foundation, Inc\\.") ) != -1 )
 	    {
 		//template string
     		if( saveOptions.FSFCopyright == ProjectSettingsBase::Remove) 
-		    (*it).replace(" YEAR Free Software Foundation, Inc","");
+		    (*it).remove(" YEAR Free Software Foundation, Inc");
 		else 
 		    (*it).replace("YEAR", QDate::currentDate().toString("yyyy"));
 	    } else
@@ -559,116 +584,180 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 	}
    }
 
-   if(!usePrefs || saveOptions.updateDescription)
-   {
-      temp="# "+saveOptions.descriptionString;
-      temp.replace( "@PACKAGE@", packageName());
-      temp.replace( "@LANGUAGE@", identityOptions.languageName);
-      // strip the ending whitespace
-      temp.replace( QRegExp("\\s*$"), "" );
-      
-      kdDebug () << "Temp is '" << temp << "'" << endl;
+    if ( ( !usePrefs || saveOptions.updateDescription )
+           && ( !saveOptions.descriptionString.isEmpty() ) )
+    {
+        temp = "# "+saveOptions.descriptionString;
+        temp.replace( "@PACKAGE@", packageName());
+        temp.replace( "@LANGUAGE@", identityOptions.languageName);
+        temp = temp.stripWhiteSpace();
 
-      found=false;
-      bool foundTemplate=false;
+        // The description strings has often buggy variants already in the file, these must be removed
+        QString regexpstr = "^#\\s+" + QRegExp::escape( saveOptions.descriptionString.stripWhiteSpace() ) + "\\s*$";
+        regexpstr.replace( "@PACKAGE@", ".*" );
+        regexpstr.replace( "@LANGUAGE@", ".*" );
+        //kdDebug() << "REGEXPSTR: " <<  regexpstr << endl;
+        QRegExp regexp ( regexpstr );
 
-      for( it = commentList.begin(); it != commentList.end(); ++it )
-      {
-         kdDebug () << "testing '" << (*it) << "'" << endl;
+        // The buggy variants exist in English too (of a time before KBabel got a translation for the corresponding language)
+        QRegExp regexpUntranslated ( "^#\\s+translation of .* to .*\\s*$" );
 
-         if((*it).contains(QRegExp("^"+temp+"$")))
-         {
-	    kdDebug () << "Match " << endl;
-            found=true;
-         }
-	 if((*it).contains(QRegExp("^# SOME DESCRIPTIVE TITLE.$")))
-	 {
-	    ait = it;
-	    foundTemplate = true;
-	 }
-       }
-       if(foundTemplate) commentList.remove(ait);
-       if(!found) commentList.prepend(temp);
-   }
+        kdDebug () << "Temp is '" << temp << "'" << endl;
 
-   if(!usePrefs || saveOptions.updateTranslatorCopyright)
-   {
-      QStringList foundAuthors;
+        found=false;
+        bool foundTemplate=false;
 
-      temp="# "+identityOptions.authorName;
-      if(!identityOptions.authorEmail.isEmpty())
-      {
-         temp+=(" <"+identityOptions.authorEmail+">");
-      }
-      temp+=", "+QDate::currentDate().toString("yyyy")+".";
+        it = commentList.begin();
+        while ( it != commentList.end() )
+        {
+            kdDebug () << "testing '" << (*it) << "'" << endl;
+            bool deleteItem = false;
 
-      for( it = commentList.begin(); it != commentList.end(); ++it )
-      {
-         if((*it).contains(QRegExp("^#.*<.+@.+>,\\s*([\\d]+[\\d\\-, ]*)|(YEAR)"))) // email address followed by year
-         {
-	    foundAuthors.append( (*it) );
-         }
-       }
+            if ( (*it) == temp )
+            {
+                kdDebug () << "Match " << endl;
+                if ( found )
+                    deleteItem = true;
+                else
+                    found=true;
+            }
+            else if ( regexp.search( *it ) >= 0 )
+            {
+                // We have a similar (translated) string (from another project or another language (perhaps typos)). Remove it.
+                deleteItem = true;
+            }
+            else if ( regexpUntranslated.search( *it ) >= 0 )
+            {
+                // We have a similar (untranslated) string (from another project or another language (perhaps typos)). Remove it.
+                deleteItem = true;
+            }
+            else if ( (*it) == "# SOME DESCRIPTIVE TITLE." )
+            {
+                // We have the standard title placeholder, remove it
+                deleteItem = true;
+            }
 
-       for( it = foundAuthors.begin() ; it != foundAuthors.end() ; ++it )
-    	    commentList.remove( (*it) );
+            if ( deleteItem )
+                it = commentList.remove( it );
+            else
+                ++it;
+        }
+        if(!found) commentList.prepend(temp);
+    }
 
-	it=qFind(foundAuthors.begin(), foundAuthors.end(), QString("# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR."));
-	if( it != foundAuthors.end() ) foundAuthors.remove( it );
+    // kdDebug() << "HEADER COMMENT: " << commentList << endl;
 
-       if(foundAuthors.size()>0)
-       {
-          found = false;
-	  bool foundAuthor = false;
+    if ( (!usePrefs || saveOptions.updateTranslatorCopyright) 
+        && ( ! identityOptions.authorName.isEmpty() ) 
+        && ( ! identityOptions.authorEmail.isEmpty() ) ) // An email address can be used as ersatz of a name
+    {
+        QStringList foundAuthors;
+    
+        temp = "# ";
+        temp += identityOptions.authorName;
+        if(!identityOptions.authorEmail.isEmpty())
+        {
+            temp+=(" <"+identityOptions.authorEmail+">");
+        }
+        temp+=", "+QDate::currentDate().toString("yyyy")+".";
 
-	  QString cy = QDate::currentDate().toString("yyyy");
+        // ### TODO: it would be nice if the entry could start with "COPYRIGHT" and have the "(C)" symbol (both not mandatory)
+        QRegExp regexpAuthorYear( "^#.*(<.+@.+>)?,\\s*([\\d]+[\\d\\-, ]*|YEAR)" );
+        QRegExp regexpYearAlone( "^# , \\d{4}.?\\s*$" );
+        it = commentList.begin();
+        while ( it != commentList.end() )
+        {
+            bool deleteItem = false;
+            if ( (*it).find ( "copyright", 0, false ) != -1 )
+            {
+                // We have a line with a copyright. It should not be moved.
+            }
+            else if ( (*it).find ( regexpYearAlone ) != -1 )
+            {
+                // We have found a year number that is preceeded by a comma.
+                // That is typical of KBabel 1.10 (and earlier?) when there is neither an author name nor an email
+                // Remove the entry
+                deleteItem = true;
+            }
+            else if ( (*it) == "# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR." )
+            {
+                // Typical placeholder, remove it.
+                deleteItem = true;
+            }
+            else if ( (*it).find ( regexpAuthorYear ) != -1 ) // email address followed by year
+            {
+                if ( foundAuthors.find( (*it) ) == foundAuthors.end() )
+                {
+                    // The author line is new (and not a duplicate), so add it to the author line list
+                    foundAuthors.append( (*it) );
+                }
+                // Delete also non-duplicated entry, as now all what is needed will be processed in foundAuthors
+                deleteItem = true;
+            }
+            
+            if ( deleteItem )
+                it = commentList.remove( it );
+            else
+                ++it;
+        }
+    
+        if( !foundAuthors.isEmpty() )
+        {
+            found = false;
+            bool foundAuthor = false;
+    
+            const QString cy = QDate::currentDate().toString("yyyy");
 
-	  for( it = foundAuthors.begin() ; it!=foundAuthors.end(); ++it )
-	  {
-		if( (*it).contains(QRegExp(identityOptions.authorName+".*"
-		    +identityOptions.authorEmail)))
-		{
-		    foundAuthor = true;
-		    if( (*it).contains(QRegExp(cy))) found = true;
-		    else ait = it;
-		}
-	   }
-	   if( !found )
-		if( !foundAuthor ) foundAuthors.append(temp);
-		else
-		{
-		    //update years
-		    int index = (*ait).findRev( QRegExp("[\\d]+[\\d\\-, ]*") );
-		    if( index == -1 ) (*ait)+=", "+cy;
-		    else (*ait).insert(index+1, QString(", ")+cy);
-		}
+            ait = foundAuthors.end();
+            for( it = foundAuthors.begin() ; it!=foundAuthors.end(); ++it )
+            {
+                if ( (*it).find( QRegExp(
+                    QRegExp::escape( identityOptions.authorName )+".*"
+                    + QRegExp::escape( identityOptions.authorEmail ) ) ) != -1 )
+                {
+                    foundAuthor = true;
+                    if( (*it).find( cy ) != -1 )
+                        found = true;
+                    else
+                        ait = it;
+                }
+            }
+            if( !found )
+            {
+                if ( !foundAuthor )
+                    foundAuthors.append(temp);
+                else if ( ait != foundAuthors.end() )
+                {
+                    //update years
+                    const int index = (*ait).findRev( QRegExp("[\\d]+[\\d\\-, ]*") );
+                    if ( index == -1 )
+                        (*ait)+=", "+cy;
+                    else
+                        (*ait).insert(index+1, QString(", ")+cy);
+                }
+                else
+                    kdDebug() << "INTERNAL ERROR: author found but iterator dangling!" << endl;
+            }
+    
+        }
+        else
+            foundAuthors.append(temp);
+        it=commentList.end();
+        do
+            --it;
+        while( ( it != commentList.begin() ) && ( (*it).find( QRegExp( "^#(\\s*$|[:,\\.])" ) ) == -1 ) );
+        ++it;
+        for( ait = foundAuthors.begin() ; ait != foundAuthors.end() ; ++ait )
+        {
+            QString s = (*ait);
 
-	}
-	else foundAuthors.append(temp);
-	it=commentList.end();
-	do
-	    --it;
-	while( (*it).contains( QRegExp( "^#\\s*$")) || (*it).contains( QRegExp( "^#[:,\\.]")));
-	it++;
-	for( ait = foundAuthors.begin() ; ait != foundAuthors.end() ; ++ait )
-	{
-	    QString s = (*ait);
+            // ensure dot at the end of copyright
+            if( !s.endsWith(".") ) s += ".";
+            commentList.insert(it, s);
+        }
+    }
 
-	    // ensure dot at the end of copyright
-	    if( !s.endsWith(".") ) s += ".";
-	    commentList.insert(it, s);
-	}
-   }
-
-   QString comment;
-   for( it = commentList.begin(); it != commentList.end(); ++it )
-   {
-      comment+=("\n"+(*it));
-   }
-
-   comment.remove(0,1);// remove first newline
-
-   oldHeader.setComment(comment);
+   oldHeader.setComment( commentList.join( "\n" ) );
 
    return oldHeader;
 }
@@ -932,7 +1021,7 @@ ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, cons
 	kdDebug(KBABEL) << "openURL - template not active" << endl;
 	d->_active = false;
 	if( error == STOPPED )
-	{
+        {
 	    delete filter;
 	    return STOPPED;
 	}
@@ -1658,6 +1747,12 @@ int Catalog::findPrevInList(const QValueList<uint>& list,uint index) const
           prevIndex=(*it);
           break;
        }
+       
+       if ( it == list.constBegin() )
+       {
+           // Decremeniting the iterator at the begin is undefined, so break the loop
+           break;
+       }
     }
 
 
@@ -1667,128 +1762,138 @@ int Catalog::findPrevInList(const QValueList<uint>& list,uint index) const
 
 QString Catalog::dateTime() const
 {
+    const QDateTime dt = QDateTime::currentDateTime();
     QString dateTimeString;
-    QDate date=QDate::currentDate();
-    QTime time=QTime::currentTime();
     
-    SaveSettings options = d->_project->saveSettings();
+    const SaveSettings options = d->_project->saveSettings();
 
     switch(options.dateFormat)
     {
-       case Qt::LocalDate:
-       {
-          return KGlobal::locale()->formatDateTime(QDateTime::currentDateTime());
-       }
-       case Qt::ISODate:
-	  d->_project->settings()->useDefaults( true );
-          dateTimeString = d->_project->settings()->customDateFormat();
-	  d->_project->settings()->useDefaults( false );
-          break;
-       case Qt::TextDate:
-          dateTimeString = options.customDateFormat;
-          break;
+        case Qt::LocalDate:
+        {
+            dateTimeString = KGlobal::locale()->formatDateTime( dt );
+            break;
+        }
+        case Qt::ISODate:
+        {
+            dateTimeString = dt.toString("yyyy-MM-dd hh:mm");
+            QTime t;
+            const int offset = KRFCDate::localUTCOffset();
+            const int correction = offset < 0 ? -60 : 60 ;
+            t = t.addSecs( offset * correction );
+            dateTimeString += ( offset < 0 ? "-" : "+" );
+            dateTimeString += t.toString("hhmm");
+            break;
+        }
+        case Qt::TextDate:
+        {
+            dateTimeString = options.customDateFormat;
+
+            const QDate date = dt.date();
+            const QTime time = dt.time();
+
+            // the year
+            dateTimeString.replace( "%Y", QString::number( date.year() ) );
+            dateTimeString.replace( "%y", QString::number( date.year() ).right(2) );
+
+            // the month
+            if(date.month()<10)
+            {
+                dateTimeString.replace( "%m", "0"+QString::number( date.month() ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%m", QString::number( date.month() ) );
+            }
+
+            dateTimeString.replace( "%f", QString::number( date.month() ) );
+
+            dateTimeString.replace( "%b", date.longMonthName(date.month()) );
+            dateTimeString.replace( "%h", date.longMonthName(date.month()) );
+
+            // the day
+            dateTimeString.replace( "%j", QString::number( date.dayOfYear() ) );
+            dateTimeString.replace( "%e", QString::number( date.day() ) );
+            if(date.day() < 10)
+            {
+                dateTimeString.replace( "%d", "0"+QString::number( date.day() ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%d", QString::number( date.day() ) );
+            }
+
+            dateTimeString.replace( "%a", date.longDayName( date.dayOfWeek() ) );
+
+
+            // hour
+            dateTimeString.replace( "%k", QString::number( time.hour() ) );
+
+            if(time.hour() < 10)
+            {
+                dateTimeString.replace( "%H", "0"+QString::number( time.hour() ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%H", QString::number( time.hour() ) );
+            }
+
+            QString zone; // AM or PM
+            int hour = time.hour();
+            if( hour > 12 )
+            {
+                zone="PM";
+                hour -= 12;
+            }
+            else
+            {
+                zone="AM";
+            }
+
+            dateTimeString.replace( "%I", QString::number( hour ) );
+
+            if(hour < 10)
+            {
+                dateTimeString.replace( "%i", "0"+QString::number( hour ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%i", QString::number( hour ) );
+            }
+
+            dateTimeString.replace( "%p", zone );
+
+            // minutes
+            if(time.minute() < 10)
+            {
+                dateTimeString.replace( "%M", "0"+QString::number( time.minute() ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%M", QString::number( time.minute() ) );
+            }
+
+            // seconds
+            if(time.second() < 10)
+            {
+                dateTimeString.replace( "%S", "0"+QString::number( time.second() ) );
+            }
+            else
+            {
+                dateTimeString.replace( "%S", QString::number( time.second() ) );
+            }
+
+            // timezone
+            dateTimeString.replace( "%Z", d->_project->identitySettings().timeZone );
+            QTime t;
+            const int offset = KRFCDate::localUTCOffset();
+            const int correction = offset < 0 ? -60 : 60;
+            t = t.addSecs( offset * correction );
+            dateTimeString.replace( "%z", ( offset < 0 ? "-" : "+" ) + t.toString("hhmm") );
+            break;
+        }
     }
-
-    // the year
-    dateTimeString.replace( "%Y", QString::number( date.year() ) );
-    dateTimeString.replace( "%y", QString::number( date.year() ).right(2) );
-
-    // the month
-    if(date.month()<10)
-    {
-       dateTimeString.replace( "%m", "0"+QString::number( date.month() ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%m", QString::number( date.month() ) );
-    }
-
-    dateTimeString.replace( "%f", QString::number( date.month() ) );
-
-    dateTimeString.replace( "%b", date.longMonthName(date.month()) );
-    dateTimeString.replace( "%h", date.longMonthName(date.month()) );
-
-    // the day
-    dateTimeString.replace( "%j", QString::number( date.dayOfYear() ) );
-    dateTimeString.replace( "%e", QString::number( date.day() ) );
-    if(date.day() < 10)
-    {
-       dateTimeString.replace( "%d", "0"+QString::number( date.day() ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%d", QString::number( date.day() ) );
-    }
-
-    dateTimeString.replace( "%a", date.longDayName( date.dayOfWeek() ) );
-
-
-    // hour
-    dateTimeString.replace( "%k", QString::number( time.hour() ) );
-
-    if(time.hour() < 10)
-    {
-       dateTimeString.replace( "%H", "0"+QString::number( time.hour() ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%H", QString::number( time.hour() ) );
-    }
-
-    QString zone;
-    int hour;
-    if( time.hour() > 12 )
-    {
-       zone="PM";
-       hour=time.hour()-12;
-    }
-    else
-    {
-       zone="AM";
-       hour=time.hour();
-    }
-
-    dateTimeString.replace( "%I", QString::number( hour ) );
-
-    if(hour < 10)
-    {
-       dateTimeString.replace( "%i", "0"+QString::number( hour ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%i", QString::number( hour ) );
-    }
-
-    dateTimeString.replace( "%p", zone );
-
-    // minutes
-    if(time.minute() < 10)
-    {
-       dateTimeString.replace( "%M", "0"+QString::number( time.minute() ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%M", QString::number( time.minute() ) );
-    }
-
-    // seconds
-    if(time.second() < 10)
-    {
-       dateTimeString.replace( "%S", "0"+QString::number( time.second() ) );
-    }
-    else
-    {
-       dateTimeString.replace( "%S", QString::number( time.second() ) );
-    }
-
-    // timezone
-    dateTimeString.replace( "%Z", d->_project->identitySettings().timeZone );
-    QTime t;
-    int sgn = KRFCDate::localUTCOffset() < 0 ? -1 : 1 ;
-    t = t.addSecs( sgn*KRFCDate::localUTCOffset()*60 );
-    dateTimeString.replace( "%z", (sgn<0 ? "-" : "+") +t.toString("hhmm"));
-
-    kdDebug () << "New date: " << dateTimeString;
+    kdDebug(KBABEL) << "New date: " << dateTimeString << endl;
     return dateTimeString;
 }
 
@@ -1861,8 +1966,7 @@ ConversionStatus Catalog::saveFileAs(const KURL &url, bool overwrite)
 
       if(status == OK)
       {
-         KURL temp(tempFile);
-         if( !KIO::NetAccess::upload( temp.url(), targetURL, NULL ) )
+         if( !KIO::NetAccess::upload( tempFile, targetURL, NULL ) )
          {
             status = OS_ERROR;
          }
@@ -1928,7 +2032,7 @@ ConversionStatus Catalog::writeFile(QString localFile , bool overwrite)
     CatalogExportPlugin* filter=0;
 
     // gimme plugin for this MIME type
-    KMimeType::Ptr mime = KMimeType::findByURL( KURL::fromPathOrURL( localFile ) );
+    KMimeType::Ptr mime = KMimeType::findByURL( KURL::fromPathOrURL( currentURL().url() ) );
     KTrader::OfferList offers = KTrader::self()->query("KBabelFilter", "('"+mime->name()+"' in [X-KDE-Export])");
     KService::Ptr ptr = offers.first();
 
@@ -1981,7 +2085,7 @@ QTextCodec* Catalog::codecForFile(QString gettextHeader)
 
    QString head = gettextHeader;
 
-   QRegExp r("Content-Type:\\s*\\w+/[-\\w]+;\\s*charset\\s*=\\s*[^\\\"\\n]+");
+   QRegExp r("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*[^\\\"\\n]+");
    int begin=r.search(head);
    int len=r.matchedLength();
    if(begin<0) {
@@ -3592,3 +3696,5 @@ void Catalog::wordCount (uint &total, uint &fuzzy, uint &untranslated) const
 }
 
 #include "catalog.moc"
+
+// kate: space-indent on; indent-width 4; replace-tabs on;
