@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -142,6 +142,14 @@ public:
    Catalog(const Catalog&);
    virtual ~Catalog();
 
+   /**
+   * Get the message context for a given message.
+   *
+   * @param index  index of the requested message
+   * @return       context for the given message
+   */
+   QString msgctxt(uint index) const;
+   
    /**
    * Get list of texts for a given message in original language. Each entry in the list
    * represents a single singular/plural form.
