@@ -18,8 +18,19 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
+  
 **************************************************************************** */
 #include "catalogitem.h"
 #include "catalogitem_private.h"
@@ -60,13 +71,26 @@ QString CatalogItem::comment() const
     return d->_comment;
 }
 
+QString CatalogItem::msgctxt(const bool noNewlines) const
+{
+    if( noNewlines )
+    {
+        QString tmp = d->_msgctxt;
+        tmp.replace("\n", " ");
+        return tmp;
+    }
+    else
+        return d->_msgctxt;
+}
+
 QStringList CatalogItem::msgid(const bool noNewlines) const
 {
     QStringList result=d->_msgid;
     if( noNewlines )
     {
-	result.clear();
-	for( QStringList::Iterator it = d->_msgid.begin() ; it != d->_msgid.end() ; it++ )
+        // ### TODO JJ: use QstringList::gres to replace inside the QStringLisz
+        result.clear();
+        for( QStringList::Iterator it = d->_msgid.begin() ; it != d->_msgid.end() ; it++ )
 	{
 	    QString resultstring = (*it);
 	    resultstring.replace("\n","");
@@ -81,6 +105,7 @@ QStringList CatalogItem::msgstr(const bool noNewlines) const
     QStringList result=d->_msgstr;
     if( noNewlines )
     {
+        // ### TODO JJ: use QstringList::gres to replace inside the QStringLisz
 	result.clear();
 	for( QStringList::Iterator it = d->_msgstr.begin() ; it != d->_msgstr.end() ; it++ )
 	{
@@ -129,6 +154,11 @@ bool CatalogItem::isValid() const
     return d->_valid;
 }
 
+void CatalogItem::setMsgctxt(QString msg)
+{
+    d->_msgctxt=msg;
+}
+
 void CatalogItem::setMsgid(QString msg)
 {
     d->_msgid=msg;
@@ -236,6 +266,11 @@ int CatalogItem::totalLines() const
    {
       lines = d->_comment.contains('\n')+1;
    }
+   int msgctxtLines=0;
+   if(!d->_msgctxt.isEmpty())
+   {
+      msgctxtLines=d->_msgctxt.contains('\n')+1;
+   }
    int msgidLines=0;
    QStringList::ConstIterator it;
    for(it=d->_msgid.begin(); it != d->_msgid.end(); ++it)
@@ -248,12 +283,14 @@ int CatalogItem::totalLines() const
       msgstrLines += (*it).contains('\n')+1;
    }
 
+   if(msgctxtLines>1)
+      msgctxtLines++;
    if(msgidLines>1)
       msgidLines++;
    if(msgstrLines>1)
       msgstrLines++;
 
-   lines+=( msgidLines+msgstrLines );
+   lines+=( msgctxtLines+msgidLines+msgstrLines );
 
    return lines;
 }
@@ -440,6 +477,7 @@ void CatalogItem::clear()
       d->_argList.clear();
    }
    d->_comment="";
+   d->_msgctxt="";
    d->_valid=true;
    d->_gettextPluralForm=false;
    d->_haveTagList=false;
@@ -452,6 +490,7 @@ void CatalogItem::clear()
 void CatalogItem::operator=(const CatalogItem& rhs)
 {
     d->_comment = rhs.d->_comment;
+    d->_msgctxt = rhs.d->_msgctxt;
     d->_msgid = rhs.d->_msgid;
     d->_msgstr = rhs.d->_msgstr;
     d->_valid = rhs.d->_valid;
