@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -512,7 +512,7 @@ void KBabelView::diffInternal(bool autoDf)
 
     if(r == Catalog::DiffNeedList)
     {
-	switch( KBabelSettings::useDBForDiff() )
+	switch( _project->settings()->useDBForDiff() )
 	{
 	    case 1:
     	    {
@@ -656,7 +656,7 @@ bool KBabelView::openDiffFile(bool autoDiff)
 
     KURL url;
 
-    if( autoDiff && ! KBabelSettings::diffBaseDir().isEmpty() )
+    if( autoDiff && ! _project->settings()->diffBaseDir().isEmpty() )
     {
         KURL fileURL = _catalog->currentURL();
 	
@@ -670,10 +670,10 @@ bool KBabelView::openDiffFile(bool autoDiff)
            if(fileRelPath[0] == '/')
                fileRelPath=fileRelPath.mid(1);
 
-           if(KBabelSettings::diffBaseDir().right(1) != "/")
-               KBabelSettings::diffBaseDir() += '/';
+           if(_project->settings()->diffBaseDir().right(1) != "/")
+               _project->settings()->diffBaseDir() += '/';
 
-           QString diffFilePath = KBabelSettings::diffBaseDir() + fileRelPath;
+           QString diffFilePath = _project->settings()->diffBaseDir() + fileRelPath;
 
 
            KURL diffFileURL(diffFilePath);
@@ -691,7 +691,7 @@ bool KBabelView::openDiffFile(bool autoDiff)
 
     if(url.isEmpty())
     {
-        url = KFileDialog::getOpenURL(KBabelSettings::diffBaseDir(), i18n("*.po *.pot|Gettext Files")
+        url = KFileDialog::getOpenURL(_project->settings()->diffBaseDir(), i18n("*.po *.pot|Gettext Files")
                ,this, i18n("Select File to Diff With"));
     }
 
@@ -741,13 +741,13 @@ bool KBabelView::openDiffFile(bool autoDiff)
 	    case NO_PLUGIN:
 	    {
 	         KMessageBox::error(this,i18n(
-	              "KBabel cannot find a corresponding plugin for the MIME type of the file:\n %1").arg(url.url()));
+	              "KBabel cannot find a corresponding plugin for the MIME type of the file:\n %1").arg(url.prettyURL()));
 	         break;
 	    }
 	    case UNSUPPORTED_TYPE:
 	    {
 	          KMessageBox::error(this,i18n(
-	               "The import plugin cannot handle this type of the file:\n %1").arg(url.url()));
+	               "The import plugin cannot handle this type of the file:\n %1").arg(url.prettyURL()));
                   break;
 	    }
             default:
