@@ -21,14 +21,14 @@
 #include "navviewitem.h"
 
 NavViewItem::NavViewItem(NavView *parent, QObject *obj )
-  : QListViewItem(parent, obj->name(), obj->className() )
+  : KListViewItem(parent, obj->name(), obj->className() )
 {
   data = obj;
   setExpandable( true );
 }
 
 NavViewItem::NavViewItem(NavViewItem *parent, QObject *obj )
-  : QListViewItem(parent, obj->name(), obj->className() )
+  : KListViewItem(parent, obj->name(), obj->className() )
 {
   data = obj;
   setExpandable( true );
