@@ -28,6 +28,16 @@
 ;*    Functions  ...                                                   */
 ;*---------------------------------------------------------------------*/
 
+;; Helper for kde-file-get-cpp-h
+(defun kde-find-file (filename basedir)
+  "Looks for \"filename\" under \"basedir\""
+  (if basedir
+      (let ((path (concat basedir "/" filename)))
+	(if (file-readable-p path)
+	    path))
+    )
+)
+
 (defun kde-file-get-cpp-h ()
   "Function returns a corresponding source or header file. The returned
 variable is a list of the form (FILENAME IS_READABLE) e.g. when being in
@@ -37,21 +47,64 @@ return (\"test.cpp\" t)."
   (let* ((name (buffer-file-name))
 	 (nname (file-name-sans-extension name))
 	 (ext (file-name-extension name))
-	 (ret nil))
+	 (path nil)
+	 (ret nil)
+	 (listit nil))
     (cond
      ((member ext kde-header-files)
-      (dolist (elt kde-source-files nil)
-	(if (file-readable-p (concat nname "." elt))
-	    (setq ret (cons (concat nname "." elt) t)))
+      (setq listit kde-source-files)
+      (while (and listit (not ret)) ; loop over the list but stop once ret is set
+	(setq path (concat nname "." (car listit)))
+	(if (file-readable-p path)
+	    (setq ret (cons path t))
+	  )
+	(if (not ret)
+	    (if (string-match "_p$" nname)
+		(progn 
+		  (setq path (concat (substring nname 0 (string-match "_p$" nname)) "." (car listit)))
+		  (if (file-readable-p path)
+		      (setq ret (cons path t))
+		    )))
+	  )
+	(if (not ret)
+	    (progn ; look in kde-source-directory
+	      (setq path (kde-find-file (file-name-nondirectory path) kde-source-directory))
+	      (if (and
+		   path
+		   (file-readable-p path))
+		  (setq ret (cons path t))
+		))
+	  )
+	(setq listit (cdr listit)) ; ++listit
 	)
+      ; not found, will create one
       (if (not ret)
 	  (setq ret (cons (concat nname "." kde-prefered-source-extension) nil ))
 	))
+
      ((member ext kde-source-files)
-      (dolist (elt kde-header-files nil)
-	(if (file-readable-p (concat nname "." elt))
-	    (setq ret (cons (concat nname "." elt) t)))
+      (setq listit kde-header-files)
+      (while (and listit (not ret)) ; loop over the list but stop once ret is set
+	(setq path (concat nname "." (car listit)))
+        ; look in current dir
+	(if (file-readable-p path)
+	    (setq ret (cons path t)))
+	(if (not ret) ;check for header_p.h files
+	    (progn (setq path (concat nname "_p." (car listit)))
+		   (if (file-readable-p path)
+		       (setq ret (cons path t)))))
+	(if (not (file-readable-p path))
+	    (progn ;  look in kde-include-directory
+	      (setq path (kde-find-file (file-name-nondirectory path) kde-include-directory))
+	      (if (and 
+		   path
+		   (file-readable-p path))
+		  (setq ret (cons path t))
+		))
+	  )
+	(setq listit (cdr listit)) ; ++listit
 	)
+      ; not found, will create one
       (if (not ret)
 	  (setq ret (cons (concat nname "." (car kde-header-files)) nil ))
 	))
